==> dl.php?src=linea21_1_0.zip: linea21/public/tpl_workshop.php <==
<?php
include_once('../workshop/display.php');
	
if (isset($_REQUEST['parentid'])&&  $_REQUEST['rub']==$GLOBALS['links']['message']['linkvalue']) 
{
if (isset($_REQUEST['parentparentid'])) $discussion_id=$_REQUEST['parentparentid'];
$workshop_id=$_REQUEST['parentid'];
$sujet_id=$_REQUEST['id'];
}
else
if (isset($_REQUEST['parentid'])) 
{
$workshop_id=$_REQUEST['parentid'];
$discussion_id=$_REQUEST['id'];
}
else if (isset($_REQUEST['id'])) $workshop_id=$_REQUEST['id'];
else $workshop_id="";

if (isset($_REQUEST['filter'])) $filter=$_REQUEST['filter'];
else $filter="";
if (isset($_REQUEST['debut']) && $_REQUEST['rub']==$GLOBALS['links']['discussion']['linkvalue']) $debut=$_REQUEST['debut'];
else {
if (isset($_REQUEST['debut']) && $_REQUEST['rub']==$GLOBALS['links']['sujet']['linkvalue']) $debut=$_REQUEST['debut'];
else $debut=0;
}
if (isset($_POST['body'])) $body=$_POST['body'];
else $body='';
if (isset($_POST['title'])) $title=$_POST['title'];
else $title='';
$test_cookie=CookieWorkshopid($workshop_id);
?>
<div id="contenu">
<?php 
if (isset($_REQUEST['id']) && !isset($_REQUEST['filter']) && $_REQUEST['rub']==$GLOBALS['links']['groupe-de-travail']['linkvalue'] || $_REQUEST['rub']==$GLOBALS['links']['calendrier']['linkvalue'] || $_REQUEST['rub']==$GLOBALS['links']['discussion']['linkvalue'] || $_REQUEST['rub']==$GLOBALS['links']['sujet']['linkvalue'] || $_REQUEST['rub']==$GLOBALS['links']['message']['linkvalue'] || $_REQUEST['rub']==$GLOBALS['links']['listeutilisateur']['linkvalue'] || $_REQUEST['rub']==$GLOBALS['links']['listerapport']['linkvalue']) {
?>
<?php 
////////////////////////////////////////////////////
/////affichage titre groupe de travail
///////////////////////////////////////////////////

DisplayOneWorkshop($workshop_id, "title");

?>
<div id="workshop"> 
<?php DisplayOneWorkshop($workshop_id);?>
<?php if ($test_cookie<>true) DisplayUrlInscription($workshop_id, $test_cookie); ?>
</div>
<br />
<div class="barre_list">
<ul>
<li>
<?php  DisplayUrlCalendar($workshop_id, $GLOBALS['lang']['workshop']['cal_all'] ); ?>
</li>
<?php if ($test_cookie==true) {
echo "<li>";
DisplayUrlDiscussion($workshop_id, $GLOBALS['lang']['workshop']['com_public'] );
echo "</li>";
} ?>
<li>
<?php  DisplayUrlListerapport($workshop_id, $GLOBALS['lang']['workshop']['barre_report'] ); ?>
</li>
<li>
<?php  DisplayUrlListeutilisateur($workshop_id, $GLOBALS['lang']['workshop']['barre_user'] ); ?>
</li>
</ul>
</div>
<br />
<?php if ($_REQUEST['rub']==$GLOBALS['links']['calendrier']['linkvalue'] || $_REQUEST['rub']==$GLOBALS['links']['groupe-de-travail']['linkvalue']) {
          
       ?>
<div id="calendar">
<h2><?php echo $GLOBALS['lang']['workshop']['calendar']; ?></h2> 
<?php DisplayCalendar($workshop_id, "ALL"); ?> 
</div>
<?php } ?>
<?
////////////////////////////////////////////////////
/////affichage rsum calendrier
///////////////////////////////////////////////////

/*
if ($_REQUEST['rub']<>$GLOBALS['links']['calendrier']['linkvalue']){?>
<div id="calendar">
<h2><?php echo $GLOBALS['lang']['workshop']['calendar'] ?></h2> 
<?php DisplayUrlAllCalendar($workshop_id); ?> 
<?php DisplayCalendar($workshop_id, 5); ?> 
</div>
<?php }
////////////////////////////////////////////////////
/////affichage calendrier entier
///////////////////////////////////////////////////

else  if ($_REQUEST['rub']==$GLOBALS['links']['calendrier']['linkvalue']) { ?>
<div id="calendar">
<h2><?php echo $GLOBALS['lang']['workshop']['calendar']; ?></h2> 
<?php DisplayCalendar($workshop_id, "ALL"); ?> 
</div>
<?php } */
//////////////////////////////////////////
/////affichage discussions
//////////////////////////////////////////
if (($_REQUEST['rub']==$GLOBALS['links']['discussion']['linkvalue'] || $_REQUEST['rub']==$GLOBALS['links']['sujet']['linkvalue'] || $_REQUEST['rub']==$GLOBALS['links']['message']['linkvalue']) && $test_cookie==true){ ?>

<?php 
//////////////////////////////////////////
/////affichage liste des discussions
//////////////////////////////////////////
if ($_REQUEST['rub']==$GLOBALS['links']['discussion']['linkvalue']){ ?>
<div id="discussion"> 
<?php DisplayListDiscussion($workshop_id, $debut); ?> 
</div>
<?php } 
//////////////////////////////////////////
/////affichage d'un sujet
//////////////////////////////////////////
if ($_REQUEST['rub']==$GLOBALS['links']['sujet']['linkvalue']){ ?>
<div id="sujet"> 
<?php 

//DisplayUrlDiscussion($workshop_id, $GLOBALS['lang']['workshop']['com_back'] );
DisplayOneDiscussion($workshop_id, $discussion_id, $debut,-1, $body, $title);

?>
</div> 
<?php } 
//////////////////////////////////////////
/////affichage d'un message
//////////////////////////////////////////
if ($_REQUEST['rub']==$GLOBALS['links']['message']['linkvalue'] ){ ?>
<?php 
if (isset($_POST['message_id'])) {
DisplayOneDiscussion($workshop_id, $_POST['discussion_id'], $debut, "ONE", $body, $title);
DisplayFormMessageMod($_POST['workshop_id'], $_POST['discussion_id'], $_POST['message_id'], $body, $title);
}
else {
DisplayOneDiscussion($workshop_id, $discussion_id, $debut, "ONE", $body, $title);
DisplayFormMessageMod($workshop_id, $discussion_id, $sujet_id, $body, $title, "NOPOST");
}
?> 
<hr />
<?php }}/*
//////////////////////////////////////////
/////affichage dtails groupe de travail
//////////////////////////////////////////
?>
<div id="workshop"> 
<?php DisplayOneWorkshop($workshop_id);?>
<?php if ($test_cookie==true) DisplayUrlDiscussion($workshop_id, $GLOBALS['lang']['workshop']['com'] );
	else DisplayUrlInscription($workshop_id, $test_cookie); ?>
<hr />
</div>
 <?php*/
 
 //////////////////////////////////////////
/////affichage utilisateurs et rapport d'un groupe de travail
//////////////////////////////////////////
 ?>
<?php if ($_REQUEST['rub']==$GLOBALS['links']['listeutilisateur']['linkvalue']) { ?>
          
<div id="user">
<h2><?php echo $GLOBALS['lang']['workshop']['participant']; ?></h2>
<?php DisplayUserWorkshop($workshop_id);?> 
</div>
<?php } 

if ($_REQUEST['rub']==$GLOBALS['links']['listerapport']['linkvalue']) {
?>
<div id="report">
<h2><?php echo $GLOBALS['lang']['workshop']['report']; ?></h2>
<?php DisplayListReport($workshop_id);?> 
</div>     
 <?php }
 }

//////////////////////////////////////////
/////affichage liste des groupes de travail
//////////////////////////////////////////

else {
if ($_REQUEST['rub']==$GLOBALS['links']['inscription-groupe-de-travail']['linkvalue']) {
 ?>
<h1>
<?php echo $GLOBALS['lang']['workshop']['creainscription']; ?>
</h1>
<?php DisplayInscription($workshop_id);
}   
else{
?>
<h1>
<?php echo $GLOBALS['lang']['workshop']['h1_public']; ?>
</h1>
<div class="h1_comment" id="h1_workshop">
<?php echo $GLOBALS['lang']['workshop']['h1_public_comment']; ?>
</div>
<?php DisplayListWorkshop($workshop_id, $filter);
}
} 
?>
</div>

==> dl.php?src=linea21_1_1.zip: linea21/public/tpl_workshop.php <==
<?php
include_once('../workshop/display.php');
	
if (isset($_REQUEST['parentid'])&&  $_REQUEST['rub']==$GLOBALS['links']['message']['linkvalue']) 
{
if (isset($_REQUEST['parentparentid'])) $discussion_id=$_REQUEST['parentparentid'];
$workshop_id=$_REQUEST['parentid'];
$sujet_id=$_REQUEST['id'];
}
else
if (isset($_REQUEST['parentid'])) 
{
$workshop_id=$_REQUEST['parentid'];
$discussion_id=$_REQUEST['id'];
}
else if (isset($_REQUEST['id'])) $workshop_id=$_REQUEST['id'];
else $workshop_id="";

if (isset($_REQUEST['filter'])) $filter=$_REQUEST['filter'];
else $filter="";
if (isset($_REQUEST['debut']) && $_REQUEST['rub']==$GLOBALS['links']['discussion']['linkvalue']) $debut=$_REQUEST['debut'];
else {
if (isset($_REQUEST['debut']) && $_REQUEST['rub']==$GLOBALS['links']['sujet']['linkvalue']) $debut=$_REQUEST['debut'];
else $debut=0;
}
if (isset($_POST['body'])) $body=$_POST['body'];
else $body='';
if (isset($_POST['title'])) $title=$_POST['title'];
else $title='';
$test_cookie=CookieWorkshopid($workshop_id);
?>
<div id="contenu">
<?php 
if (isset($_REQUEST['id']) && !isset($_REQUEST['filter']) && $_REQUEST['rub']==$GLOBALS['links']['groupe-de-travail']['linkvalue'] || $_REQUEST['rub']==$GLOBALS['links']['calendrier']['linkvalue'] || $_REQUEST['rub']==$GLOBALS['links']['discussion']['linkvalue'] || $_REQUEST['rub']==$GLOBALS['links']['sujet']['linkvalue'] || $_REQUEST['rub']==$GLOBALS['links']['message']['linkvalue'] || $_REQUEST['rub']==$GLOBALS['links']['listeutilisateur']['linkvalue'] || $_REQUEST['rub']==$GLOBALS['links']['listerapport']['linkvalue']) {
?>
<?php 
////////////////////////////////////////////////////
/////affichage titre groupe de travail
///////////////////////////////////////////////////

DisplayOneWorkshop($workshop_id, "title");

?>
<div id="workshop"> 
<?php DisplayOneWorkshop($workshop_id);?>
<?php if ($test_cookie<>true) DisplayUrlInscription($workshop_id, $test_cookie); ?>
</div>
<br />
<div class="barre_list">
<ul>
<li>
<?php  DisplayUrlCalendar($workshop_id, $GLOBALS['lang']['workshop']['cal_all'] ); ?>
</li>
<?php if ($test_cookie==true) {
echo "<li>";
DisplayUrlDiscussion($workshop_id, $GLOBALS['lang']['workshop']['com_public'] );
echo "</li>";
} ?>
<li>
<?php  DisplayUrlListerapport($workshop_id, $GLOBALS['lang']['workshop']['barre_report'] ); ?>
</li>
<li>
<?php  DisplayUrlListeutilisateur($workshop_id, $GLOBALS['lang']['workshop']['barre_user'] ); ?>
</li>
</ul>
</div>
<br />
<?php if ($_REQUEST['rub']==$GLOBALS['links']['calendrier']['linkvalue'] || $_REQUEST['rub']==$GLOBALS['links']['groupe-de-travail']['linkvalue']) {
          
       ?>
<div id="calendar">
<h2><?php echo $GLOBALS['lang']['workshop']['calendar']; ?></h2> 
<?php DisplayCalendar($workshop_id, "ALL"); ?> 
</div>
<?php } ?>
<?
////////////////////////////////////////////////////
/////affichage résumé calendrier
///////////////////////////////////////////////////

/*
if ($_REQUEST['rub']<>$GLOBALS['links']['calendrier']['linkvalue']){?>
<div id="calendar">
<h2><?php echo $GLOBALS['lang']['workshop']['calendar'] ?></h2> 
<?php DisplayUrlAllCalendar($workshop_id); ?> 
<?php DisplayCalendar($workshop_id, 5); ?> 
</div>
<?php }
////////////////////////////////////////////////////
/////affichage calendrier entier
///////////////////////////////////////////////////

else  if ($_REQUEST['rub']==$GLOBALS['links']['calendrier']['linkvalue']) { ?>
<div id="calendar">
<h2><?php echo $GLOBALS['lang']['workshop']['calendar']; ?></h2> 
<?php DisplayCalendar($workshop_id, "ALL"); ?> 
</div>
<?php } */
//////////////////////////////////////////
/////affichage discussions
//////////////////////////////////////////
if (($_REQUEST['rub']==$GLOBALS['links']['discussion']['linkvalue'] || $_REQUEST['rub']==$GLOBALS['links']['sujet']['linkvalue'] || $_REQUEST['rub']==$GLOBALS['links']['message']['linkvalue']) && $test_cookie==true){ ?>

<?php 
//////////////////////////////////////////
/////affichage liste des discussions
//////////////////////////////////////////
if ($_REQUEST['rub']==$GLOBALS['links']['discussion']['linkvalue']){ ?>
<div id="discussion"> 
<?php DisplayListDiscussion($workshop_id, $debut); ?> 
</div>
<?php } 
//////////////////////////////////////////
/////affichage d'un sujet
//////////////////////////////////////////
if ($_REQUEST['rub']==$GLOBALS['links']['sujet']['linkvalue']){ ?>
<div id="sujet"> 
<?php 

//DisplayUrlDiscussion($workshop_id, $GLOBALS['lang']['workshop']['com_back'] );
DisplayOneDiscussion($workshop_id, $discussion_id, $debut,-1, $body, $title);

?>
</div> 
<?php } 
//////////////////////////////////////////
/////affichage d'un message
//////////////////////////////////////////
if ($_REQUEST['rub']==$GLOBALS['links']['message']['linkvalue'] ){ ?>
<?php 
if (isset($_POST['message_id'])) {
DisplayOneDiscussion($workshop_id, $_POST['discussion_id'], $debut, "ONE", $body, $title);
DisplayFormMessageMod($_POST['workshop_id'], $_POST['discussion_id'], $_POST['message_id'], $body, $title);
}
else {
DisplayOneDiscussion($workshop_id, $discussion_id, $debut, "ONE", $body, $title);
DisplayFormMessageMod($workshop_id, $discussion_id, $sujet_id, $body, $title, "NOPOST");
}
?> 
<hr />
<?php }}/*
//////////////////////////////////////////
/////affichage détails groupe de travail
//////////////////////////////////////////
?>
<div id="workshop"> 
<?php DisplayOneWorkshop($workshop_id);?>
<?php if ($test_cookie==true) DisplayUrlDiscussion($workshop_id, $GLOBALS['lang']['workshop']['com'] );
	else DisplayUrlInscription($workshop_id, $test_cookie); ?>
<hr />
</div>
 <?php*/
 
 //////////////////////////////////////////
/////affichage utilisateurs et rapport d'un groupe de travail
//////////////////////////////////////////
 ?>
<?php if ($_REQUEST['rub']==$GLOBALS['links']['listeutilisateur']['linkvalue']) { ?>
          
<div id="user">
<h2><?php echo $GLOBALS['lang']['workshop']['participant']; ?></h2>
<?php DisplayUserWorkshop($workshop_id);?> 
</div>
<?php } 

if ($_REQUEST['rub']==$GLOBALS['links']['listerapport']['linkvalue']) {
?>
<div id="report">
<h2><?php echo $GLOBALS['lang']['workshop']['report']; ?></h2>
<?php DisplayListReport($workshop_id);?> 
</div>     
 <?php }
 }

//////////////////////////////////////////
/////affichage liste des groupes de travail
//////////////////////////////////////////

else {
if ($_REQUEST['rub']==$GLOBALS['links']['inscription-groupe-de-travail']['linkvalue']) {
 ?>
<h1>
<?php echo $GLOBALS['lang']['workshop']['creainscription']; ?>
</h1>
<?php DisplayInscription($workshop_id);
}   
else{
?>
<h1>
<?php echo $GLOBALS['lang']['workshop']['h1_public']; ?>
</h1>
<div class="h1_comment" id="h1_workshop">
<?php echo $GLOBALS['lang']['workshop']['h1_public_comment']; ?>
</div>
<?php DisplayListWorkshop($workshop_id, $filter);
}
} 
?>
</div>
